######################################################################
#
#  Configuration settings.  All settings you need to change start
#  with a number, e.g 1)
#
######################################################################

######################################################################
#  1 and 2) Who quota emails should be sent from
######################################################################

FROM_ADDRESS = "me@mysite.com"
FROM_NAME = "Site administrator"

######################################################################
#  3 and 4) Templates for quota notifications to resellers and user
#           quotas to site admins.
######################################################################

RESELLER_TEMPLATE   = "./templates/reseller.xml"
SITE_ADMIN_TEMPLATE = "./templates/site_admin.xml"

#######################################################################
#  5) What host to connect to for sending quota warning email
#     (in case you don't want localhost).
#######################################################################

SMTP_HOST = "localhost"

#######################################################################
#  6) Set to 1 or 0; emails will be printed to stdout instead of being 
#     mailed if set to 1.
#######################################################################

DEBUG_MODE = 1

##############################
######### SKIP THIS ##########
##############################

CONFIGURATION = None

class ThresholdInfo:
    def __init__(self):
        self.threshold = 0
        self.name = None
        self.template = None
        self.from_email = FROM_ADDRESS

class OutputOptions:
    def __init__(self):
        self.site_admin_email = 1
        self.user_email = 1
        self.user_summary_email = 1
        self.site_summary_email = 1

SITE_THRESHOLDS = []
USER_THRESHOLDS = []

def add_site_threshold(setting):
    SITE_THRESHOLDS.append(setting)

def add_user_threshold(setting):
    USER_THRESHOLDS.append(setting)

options = OutputOptions()

##############################
######### END SKIP  ##########
##############################

######################################################################
#  7)  Output options: 1 == on, 0 == off
######################################################################

#  Email site admin when site threshold is reached
options.site_admin_email = 1

#  Email user when user threshold is reached
options.user_email = 1

#  Email site admin a summary email detailing
#  users who reached thresholds

options.user_summary_email = 1

#  Email resellers a summary email detailing
#  sites that reached thresholds
options.site_summary_email = 1

######################################################################
#  8) Define thresholds here!
#
#  Each threshold must have a template, name, and threshold
#  value defined.
#
#  PLEASE DO change these to suit your needs.  PLEASE remember to
#  call add_site_threshold() or add_user_threshold() for each threshold 
#  you define!  See the examples below!
#
#  If you want to temporarily disable a threshold, just comment
#  out (put a "#" sign) before the add_threshold() call. .e.g:
#add_site_threshold(foo)
#  
######################################################################

test = ThresholdInfo()
test.name = "Test"
test.threshold = 10
test.template = "./templates/site/test.xml"
add_site_threshold(test)

info = ThresholdInfo()
info.name = "Information"
info.threshold = 60
info.template = "./templates/site/info.xml"
add_site_threshold(info)

severe = ThresholdInfo()
severe.name = "Severe"
severe.threshold = 95
severe.template = "./templates/site/severe.xml"
add_site_threshold(severe)

user_test = ThresholdInfo()
user_test.name = "User test"
user_test.threshold = 1
user_test.template = "./templates/user/test.xml"
add_user_threshold(user_test)

user_warn = ThresholdInfo()
user_warn.name = "User warning"
user_warn.threshold = 50
user_warn.template = "./templates/user/warn.xml"
add_user_threshold(user_warn)

user_severe = ThresholdInfo()
user_severe.name = "User severe"
user_severe.threshold = 95
user_severe.template = "./templates/user/severe.xml"
add_user_threshold(user_severe)

######################################################################
##########################  END CONFIGURATION  #######################
######################################################################

def sort_quota(a, b):
    if a.threshold > b.threshold:
        return -1
    elif a.threshold < b.threshold:
        return 1
    else:
        return 0

class Configuration:
    def __init__(self):
        SITE_THRESHOLDS.sort(sort_quota)
        USER_THRESHOLDS.sort(sort_quota)
        self.user_thresholds = USER_THRESHOLDS
        self.site_thresholds = SITE_THRESHOLDS
        self.site_admin_template = SITE_ADMIN_TEMPLATE
        self.reseller_template = RESELLER_TEMPLATE
        self.debug_mode = DEBUG_MODE
        self.from_address = FROM_ADDRESS
        self.from_name = FROM_NAME
        self.smtp_host = SMTP_HOST
        self.options = options


def get_configuration():

    global CONFIGURATION

    if CONFIGURATION == None:
        CONFIGURATION = Configuration()

    return CONFIGURATION
