from xml.dom import minidom
import configuration
import cache
import string

def read_template(template):
    doc = minidom.parse(template)
    subject_root = doc.getElementsByTagName('subject')[0]
    body_root    = doc.getElementsByTagName('body')[0]
    detail_root  = doc.getElementsByTagName('limit-detail')
    detail_sep_root  = doc.getElementsByTagName('detail-separator')

    detail_text = ""
    sep_text = ""

    if len(detail_root) == 1:
        detail_text = get_element_text(detail_root[0]).strip()

    if len(detail_sep_root) == 1:
        sep_text = get_element_text(detail_sep_root[0])
    
    return (get_element_text(body_root).rstrip(),
            get_element_text(subject_root).rstrip(),
            detail_text, sep_text)

def get_element_text(root):
    text = ""
    for one in root.childNodes:
        if  one.__dict__.has_key('tagName'): 
            text = text + "<%s/>" % (one.__dict__['tagName'])
        else:
            text = text + one.data
    return text 

def build_variable_dict(var_tree):

    vars = {}

    var_tree['config'] = configuration.get_configuration().__dict__

    for key in var_tree.keys():
        pairs = var_tree[key]
        prefix = key
        prefix = prefix.replace('_', '-')
        for name in pairs.keys():
            value = str(pairs[name])
            name = name.replace('_', '-')
            flattened = "%s:%s" % (prefix, name)
            vars[flattened] = value

    return vars

def substitute(vars, text):
    for key in vars.keys():
        text = text.replace("<%s/>" % (key), vars[key])
    return text

class Template:
    def __init__(self, file):
        body, subject, detail, sep = read_template(file)
        self._subject = subject
        self._body = body
        self._detail = detail
        self._sep    = sep
        self._vars = None

    def get_subject(self):
        return substitute(self._vars, self._subject)

    def get_body(self):
        return substitute(self._vars, self._body)

    def get_detail(self, vars):
        return substitute(vars, self._detail)
        
    def build_internal_dict(self, var_tree):
        self._vars = build_variable_dict(var_tree)

class SiteTemplate(Template):
    def __init__(self, limit, site):
        Template.__init__(self, limit.template)
        site_ = site.__dict__
        limit_ = limit.__dict__
        self._vars = { 'site' : site_, 'limit' : limit_ }
        self.build_internal_dict(self._vars)

    def add_reseller(self, reseller):
        self._vars['reseller'] = reseller.__dict__
        self.build_internal_dict(self._vars)
        
def get_site_template(limit, site):
    domain = site.domain
    return SiteTemplate(limit, site)

class UserTemplate(Template):
    def __init__(self, limit, user):
        Template.__init__(self, limit.template)
        user_ = user.__dict__
        limit_ = limit.__dict__
        self._vars = { 'user' : user_, 'limit' : limit_ }
        self.build_internal_dict(self._vars)

    def add_site_admin(self, admin):
        self._vars['siteadmin'] = admin.__dict__
        self.build_internal_dict(self._vars)

def get_user_template(limit, user):
    username = user.username
    return UserTemplate(limit, user)

class SiteAdminTemplate(Template):
    def __init__(self, admin, template):
        Template.__init__(self, template)
        admin_ = admin.__dict__
 
        admin_['users'] = self.make_user_detail(admin.children)
        self._vars = { 'siteadmin' : admin_ }
        self.build_internal_dict(self._vars)

    def make_user_detail(self, usernames):
        text = ""
        sep = self._sep
        for name in usernames:
            user, limit = cache.get_user_quota_info(name)
            vars =  build_variable_dict({ 'user' : user, 'limit' : limit})
            if text == "":
               text = self.get_detail(vars)
            else:
                text = sep.join([text, self.get_detail(vars)])
        return text

def get_site_admin_template(admin, template):
    return SiteAdminTemplate(admin, template)

class ResellerTemplate(Template):
    def __init__(self, admin, template):
        Template.__init__(self, template)
        admin_ = admin.__dict__
        admin_['sites'] = self.make_site_detail(admin.children)
        self._vars = { 'reseller' : admin_ }
        self.build_internal_dict(self._vars)

    def make_site_detail(self, domains):
        text = ""
        sep = self._sep
        for domain in domains:
            site, limit = cache.get_site_quota_info(domain)
            vars =  build_variable_dict({ 'site' : site, 'limit' : limit})
            if text == "":
               text = self.get_detail(vars)
            else:
                text = sep.join([text, self.get_detail(vars)])
        return text

def get_reseller_template(reseller, template):
    return ResellerTemplate(reseller, template)
